@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_view_xine.c,v 1.1.2.5 2003/05/15 13:58:08 makeinu Exp $
+ * $Id: image_view_xine.c,v 1.1.2.6 2003/06/03 16:14:58 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -351,9 +351,15 @@ cb_need_next_mrl (GimvXine *gtx, gchar **next_mrl_ret, ImageView *iv)
 static void
 cb_playback_finished (GimvXine *gtx, ImageView *iv)
 {
+   gboolean next;
+
    g_return_if_fail (IS_IMAGEVIEW (iv));
 
-   if (iv->continuance_play)
+   gtk_object_get (GTK_OBJECT (iv),
+                   "continuance_play", &next,
+                   NULL);
+
+   if (next)
       imageview_next (iv);
 
    remove_create_thumbnail_timer (iv);
