@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: comment.c,v 1.31.2.5 2003/05/21 14:39:21 makeinu Exp $
+ * $Id: comment.c,v 1.31.2.6 2003/05/31 17:34:20 makeinu Exp $
  */
 
 /*
@@ -205,7 +205,7 @@ defval_img_type (ImageInfo *info, gpointer data)
 
    filename = image_info_get_path (info);
    if (filename) {
-      const gchar *ext = gimv_mime_types_get_extention (filename);
+      const gchar *ext = gimv_mime_types_get_extension (filename);
       type = gimv_mime_types_get_type_from_ext (ext);
    }
 
