@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gtkutils.c,v 1.22.2.6 2003/05/21 14:39:21 makeinu Exp $
+ * $Id: gtkutils.c,v 1.22.2.7 2003/06/02 12:38:28 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -530,9 +530,10 @@ gtkutil_overwrite_confirm_dialog (const gchar *title, const gchar *message,
       gtk_widget_show (vbox2);
 
       dialog.iv1 = imageview_new (NULL);
-      IMAGEVIEW(dialog.iv1)->fit_to_frame_when_change_file = TRUE;
-      IMAGEVIEW(dialog.iv1)->fit_to_frame = TRUE;
-      IMAGEVIEW(dialog.iv1)->keep_aspect = TRUE;
+      gtk_object_set (GTK_OBJECT (dialog.iv1),
+                      "fit_when_change", TRUE,
+                      "keep_aspect",     TRUE,
+                      NULL);
       imageview_hide_scrollbar (IMAGEVIEW (dialog.iv1));
       gtk_widget_set_usize (dialog.iv1, -1, 150);
       gtk_box_pack_start (GTK_BOX (vbox2), dialog.iv1, TRUE, TRUE, 0);
@@ -547,6 +548,10 @@ gtkutil_overwrite_confirm_dialog (const gchar *title, const gchar *message,
       gtk_widget_show (vbox2);
 
       dialog.iv2 = imageview_new (NULL);
+      gtk_object_set (GTK_OBJECT (dialog.iv2),
+                      "fit_when_change", TRUE,
+                      "keep_aspect",     TRUE,
+                      NULL);
       imageview_hide_scrollbar (IMAGEVIEW (dialog.iv2));
       gtk_widget_set_usize (dialog.iv2, -1, 150);
       gtk_box_pack_start (GTK_BOX (vbox2), dialog.iv2, TRUE, TRUE, 0);
