@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_info.c,v 1.43.2.9 2003/05/21 14:39:21 makeinu Exp $
+ * $Id: image_info.c,v 1.43.2.10 2003/05/31 17:34:21 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -468,7 +468,7 @@ image_info_is_audio (ImageInfo *info)
 
    g_return_val_if_fail (info, FALSE);
 
-   ext  = gimv_mime_types_get_extention (info->filename);
+   ext  = gimv_mime_types_get_extension (info->filename);
    type = gimv_mime_types_get_type_from_ext (ext);
 
    if (type && !g_strncasecmp (type, "audio", 5))
