@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_view.h,v 1.35.2.13 2003/05/21 08:26:36 makeinu Exp $
+ * $Id: image_view.h,v 1.35.2.14 2003/06/02 12:38:28 makeinu Exp $
  */
 
 #ifndef __IMAGE_VIEW_H__
@@ -67,7 +67,7 @@ typedef enum
    IMAGEVIEW_ROTATE_90,
    IMAGEVIEW_ROTATE_180,
    IMAGEVIEW_ROTATE_270
-} ImageViewAngle;
+} ImageViewOrientation;
 
 
 typedef enum
@@ -80,11 +80,6 @@ typedef enum
    ImageViewPlayableReverse,
 } ImageViewPlayableStatus;
 
-typedef enum
-{
-   ImageViewSeekBarDraggingFlag   = 1 << 0
-} ImageViewPlayerFlags;
-
 
 typedef enum
 {
@@ -164,22 +159,7 @@ struct ImageView_Tag
    GimvImage       *image;
 
    /* imageview status */
-   GdkColor                  *bg_color;
-   gboolean                   show_scrollbar;
-   gboolean                   continuance_play;
-   ImageViewPlayerFlags       player_flags;
-   ImageViewPlayerVisibleType player_visible;
-
-   /* image status */
-   gfloat           x_scale;
-   gfloat           y_scale;
-   ImageViewAngle   rotate;
-   gboolean         fit_to_frame_when_change_file;
-   gboolean         fit_to_frame_zoom_out_only;
-   gboolean         fit_to_frame;
-   gboolean         keep_aspect;
-   gboolean         ignore_alpha;
-   gboolean         buffer;
+   GdkColor        *bg_color;
 
    ImageViewPrivate *priv;
 };
@@ -221,25 +201,27 @@ void       imageview_create_thumbnail       (ImageView      *iv);
 /* creating/show/hide child widgets */
 void       imageview_change_view_mode       (ImageView      *iv,
                                              const gchar    *label);
-GtkWidget *imageview_create_zoom_menu       (GtkWidget   *window,
-                                             ImageView   *iv,
-                                             const gchar *path);
-GtkWidget *imageview_create_rotate_menu     (GtkWidget   *window,
-                                             ImageView   *iv,
-                                             const gchar *path);
-GtkWidget *imageview_create_popup_menu      (GtkWidget   *window,
-                                             ImageView   *iv,
-                                             const gchar *path);
-GtkWidget *imageview_create_movie_menu      (GtkWidget   *window,
-                                             ImageView   *iv,
-                                             const gchar *path);
-GtkWidget *imageview_create_view_modes_menu (GtkWidget   *window,
-                                             ImageView   *iv,
-                                             const gchar *path);
-void       imageview_set_progressbar        (ImageView   *iv,
-                                             GtkWidget   *progressbar);
-void       imageview_set_player_visible     (ImageView   *iv,
+GtkWidget *imageview_create_zoom_menu       (GtkWidget      *window,
+                                             ImageView      *iv,
+                                             const gchar    *path);
+GtkWidget *imageview_create_rotate_menu     (GtkWidget      *window,
+                                             ImageView      *iv,
+                                             const gchar    *path);
+GtkWidget *imageview_create_popup_menu      (GtkWidget      *window,
+                                             ImageView      *iv,
+                                             const gchar    *path);
+GtkWidget *imageview_create_movie_menu      (GtkWidget      *window,
+                                             ImageView      *iv,
+                                             const gchar    *path);
+GtkWidget *imageview_create_view_modes_menu (GtkWidget      *window,
+                                             ImageView      *iv,
+                                             const gchar    *path);
+void       imageview_set_progressbar        (ImageView      *iv,
+                                             GtkWidget      *progressbar);
+void       imageview_set_player_visible     (ImageView      *iv,
                                              ImageViewPlayerVisibleType type);
+ImageViewPlayerVisibleType
+           imageview_get_player_visible     (ImageView      *iv);
 void       imageview_show_scrollbar         (ImageView      *iv);
 void       imageview_hide_scrollbar         (ImageView      *iv);
 void       imageview_popup_menu             (ImageView      *iv,
@@ -272,9 +254,11 @@ gboolean   imageview_get_image_size         (ImageView   *iv,
 
 /* rotatable interface */
 void       imageview_rotate_image           (ImageView   *iv,
-                                             ImageViewAngle angle);
+                                             ImageViewOrientation angle);
 void       imageview_rotate_ccw             (ImageView   *iv);
 void       imageview_rotate_cw              (ImageView   *iv);
+ImageViewOrientation
+           imageview_get_orientation        (ImageView   *iv);
 
 /* scrollable interface */
 /*
@@ -376,7 +360,7 @@ typedef guint      (*ImageViewDrawAreaGetLengthFn)       (ImageView *iv);
 typedef guint      (*ImageViewDrawAreaGetPositionFn)     (ImageView *iv);
 
 
-#define GIMV_IMAGE_VIEW_IF_VERSION 2
+#define GIMV_IMAGE_VIEW_IF_VERSION 3
 
 struct ImageViewPlugin_Tag
 {
