@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_window.c,v 1.73.2.25 2003/05/21 08:26:36 makeinu Exp $
+ * $Id: image_window.c,v 1.73.2.27 2003/06/03 16:31:35 makeinu Exp $
  */
 
 #include <stdlib.h>
@@ -289,6 +289,7 @@ create_imageview_menus (ImageWindow *iw)
 {
    guint n_menu_items;
    GtkWidget *zoom_menu, *rotate_menu, *movie_menu, *vmode_menu;
+   gboolean show_scrollbar, keep_buffer;
 
    /* main menu */
    n_menu_items = sizeof (imagewin_menu_items)
@@ -339,7 +340,12 @@ create_imageview_menus (ImageWindow *iw)
    iw->iv->imageview_popup = iw->view_menu;
 
    /* initialize menubar check items */
-   menu_check_item_set_active (iw->menubar,   "/File/Memory Buffer", iw->iv->buffer);
+   gtk_object_get (GTK_OBJECT (iw->iv),
+                   "show_scrollbar", &show_scrollbar,
+                   "keep_buffer",    &keep_buffer,
+                   NULL);
+
+   menu_check_item_set_active (iw->menubar, "/File/Memory Buffer", keep_buffer);
 
    menu_check_item_set_active (iw->view_menu, "/Menu Bar",
                                iw->flags & ImgWinShowMenuBarFlag);
@@ -349,8 +355,7 @@ create_imageview_menus (ImageWindow *iw)
                                iw->flags & ImgWinShowPlayerFlag);
    menu_check_item_set_active (iw->view_menu, "/Status Bar",
                                iw->flags & ImgWinShowStatusBarFlag);
-   menu_check_item_set_active (iw->view_menu, "/Scroll Bar", 
-                               iw->iv->show_scrollbar);
+   menu_check_item_set_active (iw->view_menu, "/Scroll Bar",  show_scrollbar);
    menu_check_item_set_active (iw->view_menu, "/Maximize",
                                iw->flags & ImgWinMaximizeFlag);
    menu_check_item_set_active (iw->view_menu, "/Full Screen",
@@ -396,6 +401,7 @@ create_toolbar (ImageWindow *iw, GtkWidget *container)
       N_("270"),
       NULL,
    };
+   gfloat x_scale, y_scale;
 
    toolbar = gtkutil_create_toolbar ();
 
@@ -487,8 +493,13 @@ create_toolbar (ImageWindow *iw, GtkWidget *container)
                                     GTK_SIGNAL_FUNC (cb_toolbar_zoom_fit),
                                     iw);
 
+   gtk_object_get (GTK_OBJECT (iw->iv),
+                   "x_scale", &x_scale,
+                   "y_scale", &y_scale,
+                   NULL);
+
    /* x scale spinner */
-   adj = (GtkAdjustment *) gtk_adjustment_new (iw->iv->x_scale,
+   adj = (GtkAdjustment *) gtk_adjustment_new (x_scale,
                                                MIN_THUMB_SIZE, MAX_THUMB_SIZE,
                                                1.0, 5.0, 0.0);
    spinner = gtkutil_create_spin_button (adj);
@@ -502,7 +513,7 @@ create_toolbar (ImageWindow *iw, GtkWidget *container)
                        GTK_SIGNAL_FUNC(cb_scale_spinner_key_press), iw);
 
    /* y scale spinner */
-   adj = (GtkAdjustment *) gtk_adjustment_new (iw->iv->y_scale,
+   adj = (GtkAdjustment *) gtk_adjustment_new (y_scale,
                                                MIN_THUMB_SIZE, MAX_THUMB_SIZE,
                                                1.0, 5.0, 0.0);
    spinner = gtkutil_create_spin_button (adj);
@@ -647,21 +658,28 @@ static void
 imagewin_set_win_size (ImageWindow *iw)
 {
    gint x_size, y_size, width, height;
-   gfloat x_scale, y_scale;
+   gfloat x_scale, y_scale, tmp;
+   gboolean show_scrollbar;
+   ImageViewOrientation rotate;
 
    if (!iw->window) return;
    if (iw->flags & ImgWinMaximizeFlag) return;
    if (iw->flags & ImgWinFullScreenFlag) return;
-   if (iw->iv->x_scale < 0.001 || iw->iv->y_scale < 0.001) return;
 
-   if (iw->iv->rotate == 0 || iw->iv->rotate == 2) {
-      x_scale = iw->iv->x_scale;
-      y_scale = iw->iv->y_scale;
+   gtk_object_get (GTK_OBJECT (iw->iv),
+                   "x_scale", &x_scale,
+                   "y_scale", &y_scale,
+                   NULL);
+   if (x_scale < 0.001 || y_scale < 0.001) return;
+
+   rotate = imageview_get_orientation (iw->iv);
+   if (rotate == 0 || rotate == 2) {
       width =  iw->iv->info->width;
       height = iw->iv->info->height;
    } else {
-      x_scale = iw->iv->y_scale;
-      y_scale = iw->iv->x_scale;
+      tmp = x_scale;
+      x_scale = y_scale;
+      y_scale = tmp;
       width  = iw->iv->info->height;
       height = iw->iv->info->width;
    }
@@ -681,7 +699,10 @@ imagewin_set_win_size (ImageWindow *iw)
    if (iw->flags & ImgWinShowStatusBarFlag)
       y_size += iw->status_bar_container->allocation.height;
 
-   if (iw->iv->show_scrollbar) {
+   gtk_object_get (GTK_OBJECT (iw->iv),
+                   "show_scrollbar", &show_scrollbar,
+                   NULL);
+   if (show_scrollbar) {
       x_size += iw->iv->vscrollbar->allocation.width;
       y_size += iw->iv->hscrollbar->allocation.height;
    }
@@ -709,6 +730,7 @@ imagewin_set_window_title (ImageWindow *iw)
    gchar buf[BUF_SIZE];
    const gchar *filename = NULL;
    gchar *dirname = NULL, *tmpstr1, *tmpstr2;
+   gboolean keep_buffer;
 
    g_return_if_fail (iw);
    if (!g_list_find (ImageWinList, iw)) return;
@@ -731,8 +753,12 @@ imagewin_set_window_title (ImageWindow *iw)
                                   conf.charset_auto_detect_fn,
                                   conf.charset_filename_mode);
 
+   gtk_object_get (GTK_OBJECT (iw->iv),
+                   "keep_buffer", &keep_buffer,
+                   NULL);
+
    if (tmpstr1 && tmpstr2 && *tmpstr1 && *tmpstr2) {
-      if (iw->iv->buffer)
+      if (keep_buffer)
          g_snprintf (buf, BUF_SIZE, _("%s (%s) - %s - "),
                      tmpstr1, tmpstr2, GIMV_PROG_NAME);
       else
@@ -740,7 +766,7 @@ imagewin_set_window_title (ImageWindow *iw)
                      tmpstr1, tmpstr2, GIMV_PROG_NAME);
       gtk_window_set_title (GTK_WINDOW (iw->window), buf);
    } else {
-      if (iw->iv->buffer)
+      if (keep_buffer)
          g_snprintf (buf, BUF_SIZE, _("- %s -"), GIMV_PROG_NAME);
       else
          g_snprintf (buf, BUF_SIZE, _("* - %s - *"), GIMV_PROG_NAME);
@@ -766,6 +792,7 @@ imagewin_set_statusbar_info (ImageWindow *iw)
    const gchar *filename = _("NONE");
    const gchar *format = _("UNKNOWN");
    gint width = 0, height = 0;
+   gboolean keep_buffer;
 
    g_return_if_fail (iw);
    if (!g_list_find (ImageWinList, iw)) return;
@@ -783,15 +810,19 @@ imagewin_set_statusbar_info (ImageWindow *iw)
                                  conf.charset_auto_detect_fn,
                                  conf.charset_filename_mode);
 
+   gtk_object_get (GTK_OBJECT (iw->iv),
+                   "keep_buffer", &keep_buffer,
+                   NULL);
+
    if (tmpstr && *tmpstr) {
-      if (iw->iv->buffer)
+      if (keep_buffer)
          g_snprintf (buf, BUF_SIZE, _("%s (Buffer ON)"), tmpstr);
       else
          g_snprintf (buf, BUF_SIZE, _("%s (Buffer OFF)"), tmpstr);
 
       gtk_statusbar_push (GTK_STATUSBAR (iw->status_bar1), 1, buf);
    } else {
-      if (iw->iv->buffer)
+      if (keep_buffer)
          g_snprintf (buf, BUF_SIZE, _("(Buffer ON)"));
       else
          g_snprintf (buf, BUF_SIZE, _("(Buffer OFF)"));
@@ -861,14 +892,20 @@ cb_open_thumbwin (gpointer data, guint action, GtkWidget *widget)
 static void
 cb_toggle_buffer (ImageWindow *iw, guint action, GtkWidget *widget)
 {
+   gboolean keep_buffer;
+
    if (GTK_CHECK_MENU_ITEM(widget)->active) {
       imageview_load_image_buf (iw->iv);
-      iw->iv->buffer = TRUE;
+      keep_buffer = TRUE;
    } else {
-      iw->iv->buffer = FALSE;
+      keep_buffer = FALSE;
       imageview_free_image_buf (iw->iv);
    }
 
+   gtk_object_set (GTK_OBJECT (iw->iv),
+                   "keep_buffer", keep_buffer,
+                   NULL);
+
    imagewin_set_window_title (iw);
    imagewin_set_statusbar_info (iw);
 }
@@ -900,7 +937,9 @@ cb_window_close (ImageWindow *iw, guint action, GtkWidget *widget)
 static void
 cb_ignore_alpha (ImageWindow *iw, guint action, GtkWidget *widget)
 {
-   iw->iv->ignore_alpha = GTK_CHECK_MENU_ITEM(widget)->active;
+   gtk_object_set (GTK_OBJECT (iw->iv),
+                   "ignore_alpha", GTK_CHECK_MENU_ITEM (widget)->active,
+                   NULL);
    imageview_show_image (iw->iv);
 }
 
@@ -1013,7 +1052,7 @@ cb_switch_player (ImageWindow *iw,
    g_return_if_fail (IS_IMAGEVIEW (iw->iv));
 
    imageview_set_player_visible (iw->iv, visible);
-   iw->player_visible = iw->iv->player_visible;
+   iw->player_visible = imageview_get_player_visible (iw->iv);
 }
 
 
@@ -1232,10 +1271,15 @@ static void
 cb_toolbar_keep_aspect (GtkWidget *widget, ImageWindow *iw)
 {
    gfloat scale;
+   gboolean keep_aspect;
 
    g_return_if_fail (iw);
 
-   if (!iw->iv->keep_aspect)
+   gtk_object_get (GTK_OBJECT (iw->iv),
+                   "keep_aspect", &keep_aspect,
+                   NULL);
+
+   if (!keep_aspect)
       return;
 
    scale = gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (iw->button.xscale));
@@ -1583,6 +1627,9 @@ cb_unset_list (ImageView *iv, ImageWindow *iw)
 static void
 cb_rendered (ImageView *iv, ImageWindow *iw)
 {
+   gfloat x_scale, y_scale;
+   ImageViewOrientation rotate;
+
    g_return_if_fail (iw);
    if (!g_list_find (ImageWinList, iw)) return;
 
@@ -1599,15 +1646,19 @@ cb_rendered (ImageView *iv, ImageWindow *iw)
    if (!(iw->flags & ImgWinMaximizeFlag) && conf.imgwin_fit_to_image)
       imagewin_set_win_size (iw);
 
+   gtk_object_get (GTK_OBJECT (iw->iv),
+                   "x_scale",     &x_scale,
+                   "y_scale",     &y_scale,
+                   "orientation", &rotate,
+                   NULL);
+
    if (iw->button.xscale)
-      gtk_spin_button_set_value (GTK_SPIN_BUTTON (iw->button.xscale),
-                                 iw->iv->x_scale);
+      gtk_spin_button_set_value (GTK_SPIN_BUTTON (iw->button.xscale), x_scale);
    if (iw->button.yscale)
-      gtk_spin_button_set_value (GTK_SPIN_BUTTON (iw->button.yscale),
-                                 iw->iv->y_scale);
+      gtk_spin_button_set_value (GTK_SPIN_BUTTON (iw->button.yscale), y_scale);
    if (iw->button.rotate)
       gtk_option_menu_set_history (GTK_OPTION_MENU (iw->button.rotate),
-                                   iw->iv->rotate);
+                                   rotate);
 }
 
 
@@ -1778,6 +1829,7 @@ void
 imagewin_change_image (ImageWindow *iw, ImageInfo *info)
 {
    GList *node;
+   gboolean fit_to_frame;
 
    g_return_if_fail (iw);
 
@@ -1789,15 +1841,15 @@ imagewin_change_image (ImageWindow *iw, ImageInfo *info)
       gdk_window_focus (iw->window->window, GDK_CURRENT_TIME);
    }
 
-   if (iw->slideshow)
-      iw->iv->fit_to_frame = conf.slideshow_fit_to_win;
-
    imageview_change_image (iw->iv, info);
 
    node = g_list_find (ImageWinList, iw);
    if (!node) return;
 
-   if (iw->iv->fit_to_frame && conf.imgwin_fit_to_image
+   gtk_object_get (GTK_OBJECT (iw->iv),
+                   "fit_when_change", &fit_to_frame,
+                   NULL);
+   if (fit_to_frame && conf.imgwin_fit_to_image
        && !(iw->flags & ImgWinMaximizeFlag))
    {
       gdk_window_resize (iw->window->window,
@@ -1838,9 +1890,11 @@ imagewin_store_win_state_to_config (ImageWindow *iw)
    conf.imgwin_show_toolbar       = iw->flags & ImgWinShowToolBarFlag;
    conf.imgwin_show_player        = iw->flags & ImgWinShowPlayerFlag;
    conf.imgwin_show_statusbar     = iw->flags & ImgWinShowStatusBarFlag;
-   conf.imgview_scrollbar         = iw->iv->show_scrollbar;
    conf.imgview_player_visible    = iw->player_visible;
-   conf.imgview_movie_continuance = iw->iv->continuance_play;
+   gtk_object_get (GTK_OBJECT (iw->iv),
+                   "show_scrollbar",   &conf.imgview_scrollbar,
+                   "continuance_play", &conf.imgview_movie_continuance,
+                   NULL);
 }
 
 
