@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: image_window.h,v 1.19.2.5 2003/05/16 14:48:46 makeinu Exp $
+ * $Id: image_window.h,v 1.19.2.6 2003/06/03 12:35:20 makeinu Exp $
  */
 
 #ifndef __IMAGE_WINDOW_H__
@@ -82,10 +82,6 @@ struct ImageWindow_Tag
    /* sub menus */
    GtkWidget       *view_menu;
    GtkWidget       *move_menu;
-   /*   these menus are held by ImageView.
-   GtkWidget       *zoom_menu;
-   GtkWidget       *rotate_menu;
-   */
    GtkWidget       *help_menu;
 
    /* flags */
