@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs.c,v 1.71.2.12 2003/05/22 03:44:56 makeinu Exp $
+ * $Id: prefs.c,v 1.71.2.15 2003/06/03 12:35:20 makeinu Exp $
  */
 
 #include <stdio.h>
@@ -150,8 +150,9 @@ static ConfParam param_imageview [] = {
    {"imgview_fit_image_to_win",   D_BOOL,   "TRUE",    &conf.imgview_fit_image_to_win},
    {"imgview_fit_image_zoom_out_only", D_BOOL, "TRUE", &conf.imgview_fit_image_zoom_out_only},
    {"imgview_keep_aspect",        D_BOOL,   "TRUE",    &conf.imgview_keep_aspect},
-   {"imgview_scale",              D_INT,    "100",     &conf.imgview_scale},
+   {"imgview_scale",              D_FLOAT,  "100.0",   &conf.imgview_scale},
    {"imgview_buffer",             D_BOOL,   "FALSE",   &conf.imgview_buffer},
+   {"imgview_auto_rotation",      D_BOOL,   "FALSE",   &conf.imgview_auto_rotation},
    {"imgview_scrollbar",          D_BOOL,   "TRUE",    &conf.imgview_scrollbar},
    {"imgview_player_visible",     D_ENUM,   "2",       &conf.imgview_player_visible},
    {"imgview_scroll_nolimit",     D_BOOL,   "FALSE",   &conf.imgview_scroll_nolimit},
@@ -223,10 +224,11 @@ static ConfParam param_preview [] = {
    {"preview_fit_image_to_frame", D_BOOL, "TRUE",  &conf.preview_fit_image_to_frame},
    {"preview_fit_image_zoom_out_only", D_BOOL, "TRUE", &conf.preview_fit_image_zoom_out_only},
    {"preview_keep_aspect",        D_BOOL, "TRUE",  &conf.preview_keep_aspect},
-   {"preview_scale",              D_INT,  "100",   &conf.preview_scale},
+   {"preview_scale",              D_FLOAT,"100.0", &conf.preview_scale},
    {"preview_scrollbar",          D_BOOL, "TRUE",  &conf.preview_scrollbar},
    {"preview_player_visible",     D_ENUM, "2",     &conf.preview_player_visible},
    {"preview_buffer",             D_BOOL, "FALSE", &conf.preview_buffer},
+   {"preview_auto_rotation",      D_BOOL, "FALSE", &conf.preview_auto_rotation},
    {"preview_mouse_button",       D_STRING,
     "0,0,0,0; -1,-2,0,0; -4,0,0,0; 5,0,0,0; 2,0,0,0; 1,0,0,0",
     &conf.preview_mouse_button},
@@ -270,7 +272,7 @@ static ConfParam param_comment [] = {
 
 static ConfParam param_slideshow [] = {
    {"slideshow_fit_to_win",     D_BOOL, "FALSE", &conf.slideshow_fit_to_win},
-   {"slideshow_img_scale",      D_INT,  "100",   &conf.slideshow_img_scale},
+   {"slideshow_img_scale",      D_FLOAT,"100.0", &conf.slideshow_img_scale},
    {"slideshow_screen_mode",    D_ENUM, "0",     &conf.slideshow_screen_mode},
    {"slideshow_menubar",        D_BOOL, "FALSE", &conf.slideshow_menubar},
    {"slideshow_toolbar",        D_BOOL, "FALSE", &conf.slideshow_toolbar},
