@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_ui_imagewin.c,v 1.3.2.3 2003/05/15 13:58:22 makeinu Exp $
+ * $Id: prefs_ui_imagewin.c,v 1.3.2.6 2003/06/03 12:35:21 makeinu Exp $
  */
 
 #include <string.h>
@@ -423,6 +423,14 @@ prefs_imagewin_image_page (void)
                                          &config_changed->imgview_buffer);
    gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
 
+#ifdef ENABLE_EXIF
+   /* enable or disable automatic rotation by exif data */
+   toggle = gtkutil_create_check_button (_("Automatic rotation by EXIF data"),
+                                         conf.imgview_auto_rotation,
+                                         gtkutil_get_data_from_toggle_cb,
+                                         &config_changed->imgview_auto_rotation);
+   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
+#endif /* ENABLE_EXIF */
    gtk_widget_set_sensitive (prefs_win.image_fit_only_zoom_out,
                              conf.imgview_fit_image_to_win);
    gtk_widget_set_sensitive (prefs_win.image_scale_spin,
@@ -478,11 +486,15 @@ prefs_ui_imagewin_image_apply (GimvPrefsWinAction action)
 
       if (iw->iv) {
          if (!dest->imgview_fit_image_to_win) {
-            iw->iv->x_scale = dest->imgview_scale;
-            iw->iv->y_scale = dest->imgview_scale;
+            gtk_object_set (GTK_OBJECT (iw->iv),
+                            "x_scale", dest->imgview_scale,
+                            "y_scale", dest->imgview_scale,
+                            NULL);
          }
-         iw->iv->fit_to_frame_when_change_file
-            = dest->imgview_fit_image_to_win;
+         gtk_object_set (GTK_OBJECT (iw->iv),
+                         "fit_when_change",   dest->imgview_fit_image_to_win,
+                         "fit_zoom_out_only", dest->imgview_fit_image_zoom_out_only,
+                         NULL);
       }
    }
 
