@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: prefs_ui_thumbwin.c,v 1.3.2.6 2003/05/17 17:43:28 makeinu Exp $
+ * $Id: prefs_ui_thumbwin.c,v 1.3.2.8 2003/06/03 12:35:21 makeinu Exp $
  */
 
 #include <string.h>
@@ -1074,6 +1074,14 @@ prefs_preview_page (void)
                                          &config_changed->preview_buffer);
    gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
 
+#ifdef ENABLE_EXIF
+   /* enable or disable automatic rotation by exif data */
+   toggle = gtkutil_create_check_button (_("Automatic rotation by EXIF data"),
+                                         conf.preview_auto_rotation,
+                                         gtkutil_get_data_from_toggle_cb,
+                                         &config_changed->preview_auto_rotation);
+   gtk_box_pack_start (GTK_BOX (vbox), toggle, FALSE, FALSE, 0);
+#endif /* ENABLE_EXIF */
 
    set_sensitive_preview  ();
 
@@ -1215,13 +1223,15 @@ prefs_ui_preview_apply (GimvPrefsWinAction action)
 
       if (tw->iv) {
          if (!dest->preview_fit_image_to_frame) {
-            tw->iv->x_scale = dest->preview_scale;
-            tw->iv->y_scale = dest->preview_scale;
+            gtk_object_set (GTK_OBJECT (tw->iv),
+                            "x_scale", dest->preview_scale,
+                            "y_scale", dest->preview_scale,
+                            NULL);
          }
-         tw->iv->fit_to_frame_when_change_file
-            = dest->preview_fit_image_to_frame;
-         tw->iv->fit_to_frame_zoom_out_only
-            = dest->preview_fit_image_zoom_out_only;
+         gtk_object_set (GTK_OBJECT (tw->iv),
+                         "fit_when_change",   dest->preview_fit_image_to_frame,
+                         "fit_zoom_out_only", dest->preview_fit_image_zoom_out_only,
+                         NULL);
       }
    }
 
